==> nodegit-0.2.4.tgz: package/src/pathspec_match_list.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/pathspec_match_list.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitPathspecMatchList::GitPathspecMatchList(git_pathspec_match_list *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitPathspecMatchList::~GitPathspecMatchList() {
   }

  void GitPathspecMatchList::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("PathspecMatchList"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("PathspecMatchList"), _constructor_template);
  }

  NAN_METHOD(GitPathspecMatchList::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitPathspecMatchList cannot be instantiated.");
     }

    GitPathspecMatchList* object = new GitPathspecMatchList(static_cast<git_pathspec_match_list *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitPathspecMatchList::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitPathspecMatchList::constructor_template)->NewInstance(2, argv));
  }

  git_pathspec_match_list *GitPathspecMatchList::GetValue() {
    return this->raw;
  }

  git_pathspec_match_list **GitPathspecMatchList::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitPathspecMatchList::constructor_template;

==> nodegit-0.2.5.tgz: package/src/pathspec_match_list.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/pathspec_match_list.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitPathspecMatchList::GitPathspecMatchList(git_pathspec_match_list *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitPathspecMatchList::~GitPathspecMatchList() {
   }

  void GitPathspecMatchList::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("PathspecMatchList"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("PathspecMatchList"), _constructor_template);
  }

  NAN_METHOD(GitPathspecMatchList::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitPathspecMatchList cannot be instantiated.");
     }

    GitPathspecMatchList* object = new GitPathspecMatchList(static_cast<git_pathspec_match_list *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitPathspecMatchList::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitPathspecMatchList::constructor_template)->NewInstance(2, argv));
  }

  git_pathspec_match_list *GitPathspecMatchList::GetValue() {
    return this->raw;
  }

  git_pathspec_match_list **GitPathspecMatchList::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitPathspecMatchList::constructor_template;
